html,
body {
  width: 100%;
  height: 100%;
  margin: 0;
  padding: 0;
  background: transparent;
  overflow: hidden;
}

#cat-wrap {
  width: 100%;
  height: 100%;
  display: grid;
  place-items: center;
  position: absolute;
  inset: 0;
  cursor: pointer;
  user-select: none;
}

#cat-gif {
  width: 120px;
  height: 120px;
  object-fit: contain;
  filter: drop-shadow(0 3px 8px rgba(0, 0, 0, 0.35));
}

.menu {
  position: fixed;
  min-width: 88px;
  border-radius: 8px;
  background: rgba(22, 24, 36, 0.96);
  border: 1px solid rgba(127, 224, 160, 0.35);
  box-shadow: 0 8px 24px rgba(0, 0, 0, 0.35);
  padding: 6px;
  z-index: 20;
}

.menu.hidden {
  display: none;
}

#quit-btn {
  width: 100%;
  border: 0;
  border-radius: 6px;
  background: transparent;
  color: #e9edff;
  text-align: left;
  padding: 6px 8px;
  cursor: pointer;
}

#quit-btn:hover {
  background: rgba(255, 107, 107, 0.2);
}
